summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmaddcommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmaddcommand.h')
-rw-r--r--kpovmodeler/pmaddcommand.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpovmodeler/pmaddcommand.h b/kpovmodeler/pmaddcommand.h
index 97793d03..a5759ea8 100644
--- a/kpovmodeler/pmaddcommand.h
+++ b/kpovmodeler/pmaddcommand.h
@@ -38,22 +38,22 @@ public:
/**
* Command that adds a new PMObject.
*
* The object obj will be inserted as child of parent after
* the object after.
*
* If after is 0, the object becomes the first child.
*/
- PMAddCommand( PMObject* obj, PMObject* parent, PMObject* after );
+ PMAddCommand( PMObject* obj, PMObject* tqparent, PMObject* after );
/**
* Command that adds a list of new PMObjects.
*
* The object in the list will be inserted as children of parent after
* the object after.
*
- * If after is 0, the objects will be inserted as first children.
+ * If after is 0, the objects will be inserted as first tqchildren.
*/
- PMAddCommand( const PMObjectList& list, PMObject* parent, PMObject* after );
+ PMAddCommand( const PMObjectList& list, PMObject* tqparent, PMObject* after );
/**
* Deletes the command. The inserted object will be deleted, if
the command was not executed (or undo-ed) */
@@ -38,22 +38,22 @@ public:
* Command that adds a new PMObject.
*
- * The object obj will be inserted as child of parent after
+ * The object obj will be inserted as child of tqparent after
* the object after.
*
@@ -38,22 +38,22 @@ public:
* Command that adds a list of new PMObjects.
*
- * The object in the list will be inserted as children of parent after
+ * The object in the list will be inserted as tqchildren of tqparent after
* the object after.
*